@@ -17,8 +17,8 @@ multi sub app(Bailador::App $myapp) is export {
     $app = $myapp;
 }
 
-our sub import {
-    app.location = callframe(1).file.IO.dirname;
+our sub import(Str :$rootdir) {
+    app.location = $rootdir || callframe(1).file.IO.dirname;
 }
 
 sub get(Pair $x) is export {
