@@ -5,6 +5,7 @@ class Bailador::Context {
     has $!env;
     has Bailador::Request  $.request  = Bailador::Request.new;
     has Bailador::Response $.response = Bailador::Response.new;
+    has Bool $.autorender is rw = True;
 
     method env {
         Proxy.new(
@@ -16,7 +17,9 @@ class Bailador::Context {
                 $!response.headers = {};
                 $!response.headers<Content-Type> = 'text/html';
                 $!response.cookies = ();
-                $!request.env = $!env = $value;
+                $!env = $value;
+                $!request.reset($!env);
+                $!autorender = True;
             },
         );
     }
